# Converters

## Torch

### -> ONNX

> [`pytorch.py`](pytorch.py)

Build in Pytorch functionality

### -> ExecuTorch

> [`pytorch.py`](pytorch.py)

Build in Pytorch functionality

### -> TF/TFLite - nobuco

> [`nobuco.py`](nobuco.py)

[link](https://github.com/AlexanderLutsenko/nobuco)

### -> TFLite - ai_edge_torch

> [`ai_edge.py`](ai_edge.py)

google's effort of supporting torch models in TF [link](https://github.com/google-ai-edge/ai-edge-torch)

### <- ONNX

- `onnx2torch` [link](https://github.com/ENOT-AutoDL/onnx2torch)
- `onnx2pytorch` - not maintained [link](https://github.com/Talmaj/onnx2pytorch)

## TF

### -> TFLite

Build in ...

### -> ONNX - tf2onnx

by ONNX community

### <- ONNX - onnx-tf

> [`onnx-tf.py`](onnx-tf.py)

Created by ONNX community (not maintained) [link](https://github.com/onnx/onnx-tensorflow)

### <- ONNX - onnx2tf

> [`onnx2tf.py`](onnx2tf.py)

has great notes (maintained but recommends to use the following) [link](https://github.com/PINTO0309/onnx2tf?tab=readme-ov-file)
